@@ -328,7 +328,7 @@ class Pickler(object):
                 if insufficiency:
                     rv_as_list += [None] * insufficiency
 
-                if rv_as_list[0].__name__ == '__newobj__':
+                if getattr(rv_as_list[0], '__name__', '') == '__newobj__':
                     rv_as_list[0] = tags.NEWOBJ
 
                 f, args, state, listitems, dictitems = rv_as_list
@@ -452,6 +452,12 @@ class Pickler(object):
                     value = self._getref(factory)
             data['default_factory'] = value
 
+        # Sub-classes of dict
+        if hasattr(obj, '__dict__'):
+            dict_data = {}
+            self._flatten_dict_obj(obj.__dict__, dict_data)
+            data['__dict__'] = dict_data
+
         return data
 
     def _flatten_obj_attrs(self, obj, attrs, data):
